@@ -75,6 +75,8 @@ __EXPORT char *setString(char *target, size_t size, const char *src);
 __EXPORT char *addString(char *target, size_t size, const char *src);
 __EXPORT char *newString(const char *src, size_t size = 0);
 __EXPORT void delString(char *str);
+__EXPORT char *setUpper(char *string, size_t size);
+__EXPORT char *setLower(char *string, size_t size);
 __EXPORT char *find(const char *cs, char *str, size_t len = 0);
 __EXPORT char *rfind(const char *cs, char *str, size_t len = 0);
 __EXPORT char *ifind(const char *cs, char *str, size_t len = 0);
