@@ -1,4 +1,4 @@
-// Copyright (C) 2001,2002 Open Source Telecom Corporation.
+// Copyright (C) 2001-2005 Open Source Telecom Corporation.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,29 +14,26 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// As a special exception to the GNU General Public License, permission is 
-// granted for additional uses of the text contained in its release 
-// of Common C++.
-// 
-// The exception is that, if you link the Common C++ library with other files
-// to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the Common C++ library code into it.
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however    
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.    
 //
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-//
-// This exception applies only to the code released under the 
-// name Common C++.  If you copy code from other releases into a copy of
+// This exception applies only to the code released under the name GNU
+// Common C++.  If you copy code from other releases into a copy of GNU
 // Common C++, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
-// 
-// If you write modifications of your own for Common C++, it is your choice
+//
+// If you write modifications of your own for GNU Common C++, it is your choice
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.
+//
 
 /**
  * @file xml.h
@@ -97,23 +94,20 @@ public:
 	 * @return true if open is successful.
 	 * @param resource passed to Parse methods.
 	 */
-	virtual bool open(const char *resource)
-		{return true;};
+	virtual bool open(const char *resource);
 
 	/**
 	 * May perform a close operation of an i/o source when the parser
 	 * has completed operation.
 	 */
-	virtual void close(void)
-		{return;};
+	virtual void close(void);
 
 	/**
 	 * Get error logging level.
 	 *
 	 * @return error logging level.
 	 */
-	virtual Slog::Level getLogging(void)
-		{return Slog::levelCritical;};
+	virtual Slog::Level getLogging(void);
 
 	/**
 	 * Virtual to receive embedded comments in an XML document being
@@ -122,8 +116,7 @@ public:
 	 * @param text text comment extracted.
 	 * @param len length of comment.
 	 */
-	virtual void comment(const unsigned char *text, size_t len)
-		{return;};
+	virtual void comment(const unsigned char *text, size_t len);
 
 	/**
 	 * Read method to aquire data for the parser.
@@ -146,14 +139,12 @@ public:
 	/**
 	 * Identify start of document event.
 	 */
-	virtual void startDocument(void)
-		{return;};
+	virtual void startDocument(void);
 
 	/**
 	 * Identify end of document event.
 	 */
-	virtual void endDocument(void)
-		{return;};
+	virtual void endDocument(void);
 
 	/**
 	 * Identify start of an element in the document.
