@@ -68,7 +68,7 @@ namespace ost {
 #endif
 
 #if defined(HAVE_NET_IF_H) || defined(WIN32)
-#if !defined(_MSC_VER) || _MSC_VER >= 1300 
+#if !defined(_MSC_VER) || _MSC_VER >= 1300 || defined(HAVE_PLATFORMSDK)
 
 using namespace std;
 
