@@ -757,11 +757,12 @@ size_t String::setSize(size_t chars)
 	if(chars <= minsize && !isBig())
 		return minsize;
 
-	if(chars <= slotlimit)
-	{
-		chars = chars / slotsize;
-		++chars *= slotsize;
-	}
+  if(chars <= slotlimit)
+  {
+    size_t slotcount = chars / slotsize;
+    if((chars % slotsize)!=0) ++slotcount;
+    chars = slotcount*slotsize;
+  }
 	content.bigstring.size = chars;
 	return chars;
 }
