@@ -557,7 +557,11 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeNormal))
 		setName("main()");
 	}
 	else
+#ifdef	WIN32
+		_name[0] = 0;
+#else
 		snprintf(_name, sizeof(_name), "%d", getId());
+#endif
 
 	_parent = Thread::get();
 	if(_parent)
@@ -1452,6 +1456,9 @@ unsigned __stdcall Thread::Execute(Thread *th)
 
 	try
 	{
+		th->priv->_tid = GetCurrentThreadId();
+		if(!th->_name[0])
+			snprintf(th->_name, sizeof(th->_name), "%d", GetCurrentThreadId());
 		th->initial();
 		if(th->getCancel() == cancelInitial) 
 			th->setCancel(cancelDefault);
